summaryrefslogtreecommitdiff
path: root/png.c
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2002-08-23 23:07:42 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-04-06 16:07:27 -0500
commit51d9250c88aa62f3aaf7c1f72209513035066074 (patch)
tree45b89c43d5e0a1a06712d2d9350e933b44f7ab59 /png.c
parent8a7df0024b3498735b23ad36ef3c0b36c4db9a9b (diff)
downloadlibpng-51d9250c88aa62f3aaf7c1f72209513035066074.tar.gz
Imported from libpng-1.2.5rc1.tarv1.2.5rc1
Diffstat (limited to 'png.c')
-rw-r--r--png.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/png.c b/png.c
index 9a9398078..42dbaebe3 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* libpng version 1.2.5beta2 - August 16, 2002
* Copyright (c) 1998-2002 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -13,14 +13,14 @@
#include "png.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_2_5beta2 Your_png_h_is_not_version_1_2_5beta2;
+typedef version_1_2_5rc1 Your_png_h_is_not_version_1_2_5rc1;
/* Version information for C files. This had better match the version
* string defined in png.h. */
#ifdef PNG_USE_GLOBAL_ARRAYS
/* png_libpng_ver was changed to a function in version 1.0.5c */
-const char png_libpng_ver[18] = "1.2.5beta2";
+const char png_libpng_ver[18] = "1.2.5rc1";
/* png_sig was changed to a function in version 1.0.5c */
/* Place to hold the signature string for a PNG file. */
@@ -136,7 +136,7 @@ png_check_sig(png_bytep sig, int num)
/* Function to allocate memory for zlib and clear it to 0. */
#ifdef PNG_1_0_X
-void PNGAPI
+voidpf PNGAPI
#else
voidpf /* private */
#endif
@@ -671,7 +671,7 @@ png_charp PNGAPI
png_get_copyright(png_structp png_ptr)
{
if (png_ptr != NULL || png_ptr == NULL) /* silence compiler warning */
- return ((png_charp) "\n libpng version 1.2.5beta2 - August 16, 2002\n\
+ return ((png_charp) "\n libpng version 1.2.5rc1 - August 24, 2002\n\
Copyright (c) 1998-2002 Glenn Randers-Pehrson\n\
Copyright (c) 1996-1997 Andreas Dilger\n\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.\n");
@@ -689,8 +689,8 @@ png_get_libpng_ver(png_structp png_ptr)
{
/* Version of *.c files used when building libpng */
if(png_ptr != NULL) /* silence compiler warning about unused png_ptr */
- return((png_charp) "1.2.5beta2");
- return((png_charp) "1.2.5beta2");
+ return((png_charp) "1.2.5rc1");
+ return((png_charp) "1.2.5rc1");
}
png_charp PNGAPI
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * libpng version 1.2.5beta2 - August 16, 2002
+ * libpng version 1.2.5rc1 - August 24, 2002
* Copyright (c) 1998-2002 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)